cal.DurationUnits (DurationUnits) — amici1

# `cal.DurationUnits` (DurationUnits)

Columns

- `lino.core.actors.Actor.detail_link`

- `lino_xl.lib.cal.choicelists.DurationUnits.button_text`

- `lino.core.choicelists.ChoiceList.value`

- `lino.core.choicelists.ChoiceList.text`

- `lino.core.choicelists.ChoiceList.name`

- `lino.core.choicelists.ChoiceList.remark`

- `lino.core.choicelists.ChoiceList.type`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

## Filter parameters